/*****************************************************************************
 * Description: Header for player.cpp                                        *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#ifndef PLAYER_H
#define PLAYER_H

#include <qobject.h>
#include <qthread.h>
#include <qevent.h>
#include <qstring.h>
#include <qapplication.h>

#include "threads.h"

class PlaylistEntry;
class Player;

class PlayerThread : public QThread
{
public:
    enum GainSelection
    {
	NoGain,
	TrackGain,
	AlbumGain
    };

    PlayerThread(Player *pl);
    virtual ~PlayerThread();
    
    virtual void run();
    
    void stop();
    void playpause(const char* fname);
    void next(const char* fname);
    void seek(int pos);
    void selectGain(GainSelection sel);

private:
    Player *player;
    
    QMutex mutex;
    QWaitCondition cond; // To restart the player.
    
    int shouldstop;
    int shouldpause;
    int notplaying;
    int shouldseek;
    GainSelection whichgain;
    
    char nextname[4096];
    char pcmdata[4096];
    unsigned char filedata[4096];
};

class Player : public QObject
{
    Q_OBJECT

public:
    Player();
    virtual ~Player();
    
    enum PlayerEvents
    {
	EvPosition	= QEvent::User + 1,
	EvNameChange	= QEvent::User + 2,
	EvSongEnded	= QEvent::User + 3,
    };
    
signals:
    void changeName(const QString& name);
    void position(int pos);
    void songEnded();

public slots:
    void stop();
    void playpause();
    void select(PlaylistEntry* file, bool waitforend);
    void select(PlaylistEntry* file);
    void seek(int promille);
    void selectNoGain();
    void selectTrackGain();
    void selectAlbumGain();

protected:
    virtual bool event(QEvent * e);

private:
    PlayerThread thread;
    QString currentfile;
};

#endif
