/*****************************************************************************
 * Description: Header for playlist.cpp                                      *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#ifndef PLAYLIST_H
#define PLAYLIST_H

#include <qobject.h>
#include <vector>

class PlaylistEntry
{
    public:
	PlaylistEntry(const QString& filename);
    
	QString getFileName() const;
	void setFileName(QString str);
	
    private:
	QString filename;
};

class Playlist : public QObject
{
    Q_OBJECT

public:
    Playlist();
    virtual ~Playlist();
    
    void addEntry(PlaylistEntry* entry);
    void delEntry(PlaylistEntry* entry);
    PlaylistEntry* currentEntry() const;
    int currentPos();

    int getPosByEntry(PlaylistEntry* entry);
    PlaylistEntry* getEntryByPos(int pos);
    
    void savePlaylist(const QString& fname);
    void addPlaylist(const QString& fname);

signals:
    void selected(int pos, PlaylistEntry* entry);
    void selected(PlaylistEntry* entry);
    void entryAdded(int pos, PlaylistEntry* entry);
    void entryChanged(int pos, PlaylistEntry* entry);
    void entryRemoved(int pos, PlaylistEntry* entry);
    void entryMoved(int oldpos, PlaylistEntry* entry, int newpos);

public slots:
    void selectPos(int pos);
    void selectEntry(PlaylistEntry* entry);
    void clear();
    void delPos(int pos);
    void movePos(int oldpos, int newpos);

private:
    std::vector<PlaylistEntry*> playlist;
    typedef std::vector<PlaylistEntry*>::iterator PLIterator;

    int current;
};

#endif
