/*****************************************************************************
 * Description: Header for qtPlayer.cpp                                      *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#ifndef QTPLAYER_H
#define QTPLAYER_H

#include <qmainwindow.h>
#include <qdir.h>
#include <opie2/oconfig.h>

class QAction;
class Playlist;
class Player;
class Selector;
class PlaylistEntry;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    static QString appName() { return QString::fromLatin1("oggplay"); }

    MainWindow(QWidget* parent, const char* name,  WFlags fl );
    virtual ~MainWindow();

public slots:
    void setDocument(const QString& );
    void addToPlaylist();
    void addDirToPlaylist();
    void savePlaylist();
    
    void nextSong(PlaylistEntry* entry, bool waitforend);
    void nextSong(int playlistpos, bool waitforend);
    
    void shuffleToggled(bool val);
    void repeatToggled(bool val);
    
    void songEnded();
    void forward();
    void backward();
    
    void incVolume();
    void decVolume();
    void setGain(int val);
    
    void keyboardLock(bool val);
    void setSaver(int val);

signals:
    void keyboardGrabToggle(bool val);

protected:
    virtual void mousePressEvent(QMouseEvent* ev);
    virtual void keyPressEvent(QKeyEvent* ev);
    virtual void timerEvent(QTimerEvent* ev);
    virtual void focusOutEvent(QFocusEvent* ev);

private:
    void initUI();
    void setDisplay(bool on);
    void changeVolAlsa(int part);
    void changeVolOSS(int part);
    void changeVol(int part);
    void addDir(const QDir& dir);

    QPopupMenu *screenSaverMenu;
    QPopupMenu *gainMenu;

    Playlist* playlist;
    Player* player;
    Selector* selector;
    
    static bool hasAlsa;
    int screenSaver;
    int timeCount;
    bool keybgrabbed;
};

#endif
