/*****************************************************************************
 * Description: The playlist widget                                          *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#include <qlistbox.h>
#include <qlayout.h>
#include <qpopupmenu.h>

#include "qtPlaylist.h"
#include "qtPlayer.h"
#include "playlist.h"

qtPlaylist::qtPlaylist( QWidget* parent, const char* name,  WFlags fl )
    : QWidget( parent, name, fl ), popupitem(NULL), moveitem(NULL), popuptimer()
{

    setCaption(tr("Playlist") );

    QVBoxLayout *layout = new QVBoxLayout( this );
    listbox = new QListBox(this);
    listbox->setSelectionMode(QListBox::NoSelection);
    layout->addWidget(listbox);

    connect( listbox, SIGNAL(mouseButtonClicked(int,QListBoxItem*,const QPoint&)),
             this, SLOT( mouseClicked(int,QListBoxItem*,const QPoint&)));

    connect( listbox, SIGNAL(mouseButtonPressed(int,QListBoxItem*,const QPoint&)),
             this, SLOT( mousePressed(int,QListBoxItem*,const QPoint&)));

    popupmenu = new QPopupMenu();
    popupmenu->insertItem(tr("Remove"), this, SLOT(itemRemove()));
    popupmenu->insertItem(tr("Move"), this, SLOT(itemMove()));
    popupmenu->hide();
    connect(&popuptimer, SIGNAL(timeout()),
	    this, SLOT(showPopup()));
}

qtPlaylist::~qtPlaylist()
{

}

void qtPlaylist::select(int pos, PlaylistEntry*)
{
    listbox->setSelectionMode(QListBox::Multi);

    listbox->clearSelection();
    if(pos>=0)
	listbox->setSelected(pos, true);

    listbox->setSelectionMode(QListBox::NoSelection);
}

void qtPlaylist::updateEntry(int pos, PlaylistEntry* entry)
{
    if(pos<(int)listbox->count())
	((qtPlaylistItem*)listbox->item(pos))->updateEntry(entry);
    else
	new qtPlaylistItem(listbox, pos, entry);
}

void qtPlaylist::removeEntry(int pos, PlaylistEntry* entry)
{
    listbox->removeItem(pos);
    if(popupitem && popupitem->getEntry()==entry)
	popupitem = NULL;
    if(moveitem && moveitem->getEntry()==entry)
	moveitem = NULL;
}

void qtPlaylist::moveEntry(int oldpos, PlaylistEntry*, int newpos)
{
    QListBoxItem* item = listbox->item(oldpos);
    listbox->takeItem(item);
    listbox->insertItem(item, newpos);  
}

void qtPlaylistItem::updateEntry(PlaylistEntry* entry)
{
    song = entry;
}

void qtPlaylist::mouseClicked(int button, QListBoxItem* item, const QPoint&)
{
    if(!item)
	return;

    if(button==LeftButton && popuptimer.isActive())
    {
	popuptimer.stop();
	if(moveitem)
	{
	    emit itemMove(listbox->index(moveitem), listbox->index(item));
	    moveitem = NULL;
	}
	else
	    emit itemClicked(listbox->index(item));
    }
    else
	moveitem = NULL;
}

void qtPlaylist::mousePressed(int button, QListBoxItem* item, const QPoint&)
{
    if(!item)
	return;

    if(button==LeftButton && item)
    {
	popuptimer.start(1000, true);
	popupitem = (qtPlaylistItem*)item;
    }
}

void qtPlaylist::itemRemove()
{
    if(popupitem)
	emit itemRemove(listbox->index(popupitem));
}

void qtPlaylist::itemMove()
{
    moveitem = popupitem;
}

void qtPlaylist::showPopup()
{
    if(moveitem)
	moveitem = NULL;

    if(popupitem)
	popupmenu->exec(QCursor::pos());
}

qtPlaylistItem::qtPlaylistItem(QListBox* listbox, int pos, PlaylistEntry* entry)
    : QListBoxText(), song(entry)
{
    listbox->insertItem(this, pos);
}

QString qtPlaylistItem::text () const
{
    return song->getFileName();
}


PlaylistEntry* qtPlaylistItem::getEntry()
{
    return song;
}
