/*****************************************************************************
 * Description: Header for selector.cpp                                      *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#ifndef SELECTOR_H
#define SELECTOR_H

#include <qobject.h>
#include <qstring.h>

#include <deque>
#include <vector>

class PlaylistEntry;

class Selector : public QObject
{
    Q_OBJECT

public:
    Selector();

signals:
    void choose(PlaylistEntry* entry, bool waitforend);
    void choose(int pos, bool waitforend);

public slots:
    void entryAdded(int pos, PlaylistEntry* entry);
    void entryRemoved(int pos, PlaylistEntry* entry);
    void entryMoved(int oldpos, PlaylistEntry* entry, int newpos);
    void songSelected(int pos, PlaylistEntry* entry);
    void forward(bool waitforend);
    void backward(bool waitforend);
    void shuffleToggled(bool val);
    void repeatToggled(bool val);

private:
    template<class container> bool removeEntry(container &cont,
	PlaylistEntry* entry);
    void unplayEntries(std::deque<PlaylistEntry*>::iterator start,
	std::deque<PlaylistEntry*>::iterator end);

    bool shuffle;
    bool repeat;
    
    std::deque<PlaylistEntry*> played;
    std::vector<PlaylistEntry*> toplay;
    PlaylistEntry* lastplayed;
    int lastplayedpos;
    int lastplaylistpos;
    int playlistsize;
};

#endif
