/*****************************************************************************
 * Description: QThread replacement using Posix threads                      *
 * Copyright:   2007 by Alexander Motzkau                                    *
 * License:     GPL V2                                                       *
 *****************************************************************************/

#ifndef QT_THREAD_SUPPORT
#include "threads.h"

QThread::QThread()
{
}

QThread::~QThread()
{
}

void QThread::run()
{
}

void* QThread::entry(void* me)
{
    ((QThread*)me)->run();
    return NULL;
}

void QThread::start()
{
    pthread_create(&thread, NULL, QThread::entry, this);
}

QMutex::QMutex()
{
    pthread_mutex_init(&mutex, NULL);
}
	
void QMutex::lock()
{
    pthread_mutex_lock(&mutex);
}

void QMutex::unlock()
{
    pthread_mutex_unlock(&mutex);
}

QWaitCondition::QWaitCondition()
{
    pthread_mutex_init(&mutex, NULL);
    pthread_cond_init(&cond, NULL);
}
	
void QWaitCondition::wait(QMutex* m)
{
    pthread_mutex_lock(&mutex);
    m->unlock();
    pthread_cond_wait(&cond, &mutex);
    pthread_mutex_unlock(&mutex);
    m->lock();
}

void QWaitCondition::wakeAll()
{
    pthread_mutex_lock(&mutex);
    pthread_cond_broadcast(&cond);    
    pthread_mutex_unlock(&mutex);
}
#endif
